Utility libraries — Invenio 3.4.0a8 documentation

# Utility libraries

Above Invenio modules dependent on a number of smaller utility libraries we have developed to take care of e.g. identifier normalization, DataCite/Dublin Core metadata generation, testing and citation formatting.

- citeproc-py-styles

    - Citation Style Language (CSL) style files packaged as a Python module

- datacite

    - Python library for generating DataCite XML from Python dictionaries and registering DOIs with the DataCite DOI registration service.

- dcxml

    - Python library for generating Dublin Core XML from Python dictionaries.

- dictdiffer

    - Python library for diffing/patching/merging JSON documents.

- dojson

    - JSON to JSON rule-based transformation library.

- flask-breadcrumbs

    - Flask extension for managing breadcrumbs in web applications.

- flask-celeryext

    - Celery integration for Flask.

- flask-iiif

    - IIIF server for Flask.

- flask-menu

    - Menu generation support for Flask.

- flask-sitemap

    - Sitemaps XML generation for Flask.

- flask-webpack

    - Webpack integration for Flask.

- idutils

    - Persistent identifier validation, identification and normalization.

- jsonresolver

    - JSONRef resolver with support for local plugins.

- pynpm

    - NPM integration for Python.

- pywebpack

    - Webpack integration library for Python.

- requirements-builder

    - Python CLI tool for testing multiple versions of different Python libraries in you continuous integration system.

- xrootdpyfs

    - PyFilesystem plugin adding XRootD support.